==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_cave.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function GoCrossRoads()
    PRI()FAO(0)TRA("CS_crossroads","E0090",12,4)
end

function GoPool()
    PRI()FAO(1)TRA("CS_pool","E0093",6,15)
end

function GoSeaCave()
    PRI()FAO(0)TRA("CS_seacave","E0090",22,8)
end

function Door_UpSide()
    if(FLJ("UnlockDoor_DownSide")) then
        GoDownSide()
    else
        if(ITJ("RustKey")) then
            PRI()
            SOU("CS_022_chest_open")
            GIT("RustKey")
            MS4("\nUsed the =RUSTY KEY=.")NOD()CLO()
            FLP("UnlockDoor_DownSide")
            GIT()
            CLO()
            GoDownSide()
        else
            PRI()
            SOU("CS_022_chest_open")WAI(16)SOU("CS_022_chest_open")WAI(16)
            MS4("\nThe door is locked.")NOD()CLR()
            CAT("\nIt reads:")NOD()CLR()
            TUR()
            MS4("\nMonsters below. Entry forbidden for Mimiga.")
            CAT("\n")CAT("—King",1)NOD()
        end
    end
end

function GoDownSide()
    KEY()
    SOU("CS_011_door")
    ANP("Door_UpSide",0,1)WAI(10)HMC()
    ANP("Door_UpSide",0,0)
    MOV(4,23)WAI(50)
    SOU("CS_011_door")
    ANP("Door_DownSide",0,1)SLR(1)SMC()WAI(10)
    ANP("Door_DownSide",0,0)
end

function Door_DownSide()
    KEY()
    SOU("CS_011_door")
    ANP("Door_DownSide",0,1)WAI(10)HMC()
    ANP("Door_DownSide",0,0)
    MOV(4,17)WAI(50)
    SOU("CS_011_door")
    ANP("Door_UpSide",0,1)SLR(1)SMC()WAI(10)
    ANP("Door_UpSide",0,0)
end

function Over()
    KEY()
    MYB(0,PLY())WAS()
    MS4("masrofox：End of the current test build.")NOD()
    CAT("\nThanks for playing! Stay tuned for the next update~")NOD()
end

--钓鱼
function Fishing2()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing")
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a Blue Fish commonly")
        CAT("\nfound in wild lakes...")NOD()CLR()
        ITP("Bluefish")
        GIT("Bluefish")
        SOU("CS_038_get_item")
        DNP("Fishing2")
        FLP("Fishing2")
        CMU("CS_Fanfale1")
        CAT("\nGot a =BLUE FISH=.")WAI(160)NOD()
        RMU()
    end
end

==> ocstore25_7_23.zip: OcStore/Prgm/data/language/en-us/script/CS_cave.lua <==
function E0090()
    MNA()CMU("CS_Vivi")InitMapLayer()FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")InitMapLayer()FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")InitMapLayer()FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")InitMapLayer()FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")InitMapLayer()FAI(4)
end

function InitMapLayer()
    DNP("InitMapLayer")
    if(DIF() == 0) then
        CMP("cmpLayer1","mainLayer")
    end
end

function GoCrossRoads()
    PRI()FAO(0)TRA("CS_crossroads","E0090",12,4)
end

function GoPool()
    PRI()FAO(1)TRA("CS_pool","E0093",6,15)
end

function GoSeaCave()
    PRI()FAO(0)TRA("CS_seacave","E0090",22,8)
end

function Door_UpSide()
    if(FLJ("UnlockDoor_DownSide")) then
        GoDownSide()
    else
        if(ITJ("RustKey")) then
            PRI()
            SOU("CS_022_chest_open")
            GIT("RustKey")
            MS4("\nUsed the =RUSTY KEY=.")NOD()CLO()
            FLP("UnlockDoor_DownSide")
            GIT()
            CLO()
            GoDownSide()
        else
            PRI()
            SOU("CS_022_chest_open")WAI(16)SOU("CS_022_chest_open")WAI(16)
            MS4("\nThe door is locked.")NOD()CLR()
            CAT("\nIt reads:")NOD()CLR()
            TUR()
            MS4("\nMonsters below. Entry forbidden for Mimiga.")
            CAT("\n")CAT("—King",1)NOD()
        end
    end
end

function GoDownSide()
    KEY()
    SOU("CS_011_door")
    ANP("Door_UpSide",0,1)WAI(10)HMC()
    ANP("Door_UpSide",0,0)
    MOV(4,23)WAI(50)
    SOU("CS_011_door")
    ANP("Door_DownSide",0,1)SLR(1)SMC()WAI(10)
    ANP("Door_DownSide",0,0)
end

function Door_DownSide()
    KEY()
    SOU("CS_011_door")
    ANP("Door_DownSide",0,1)WAI(10)HMC()
    ANP("Door_DownSide",0,0)
    MOV(4,17)WAI(50)
    SOU("CS_011_door")
    ANP("Door_UpSide",0,1)SLR(1)SMC()WAI(10)
    ANP("Door_UpSide",0,0)
end

function Over()
    KEY()
    MYB(0,PLY())WAS()
    MS4("masrofox：End of the current test build.")NOD()
    CAT("\nThanks for playing! Stay tuned for the next update~")NOD()
end

--钓鱼
function Fishing2()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing")
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a Blue Fish commonly")
        CAT("\nfound in wild lakes...")NOD()CLR()
        ITP("Bluefish")
        GIT("Bluefish")
        SOU("CS_038_get_item")
        DNP("Fishing2")
        FLP("Fishing2")
        CMU("CS_Fanfale1")
        CAT("\nGot a =BLUE FISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

--钓鱼（普通）
function Fishing3_Normal()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing")
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a Blue Fish commonly")
        CAT("\nfound in wild lakes...")NOD()CLR()
        ITP("Bluefish")
        GIT("Bluefish")
        SOU("CS_038_get_item")
        DNP("Fishing3_Normal")
        FLP("Fishing3_Normal")
        CMU("CS_Fanfale1")
        CAT("\nGot a =BLUE FISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

--钓鱼（普通）
function Fishing4_Normal()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing")
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a Blue Fish commonly")
        CAT("\nfound in wild lakes...")NOD()CLR()
        ITP("Bluefish")
        GIT("Bluefish")
        SOU("CS_038_get_item")
        DNP("Fishing4_Normal")
        FLP("Fishing4_Normal")
        CMU("CS_Fanfale1")
        CAT("\nGot a =BLUE FISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end
